"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const utils_js_1 = require("../utils.js");
const operation_object_js_1 = __importDefault(require("./operation-object.js"));
function transformPathItemObject(pathItem, { path, ctx }) {
    let { indentLv } = ctx;
    const output = [];
    output.push("{");
    indentLv++;
    for (const method of ["get", "put", "post", "delete", "options", "head", "patch", "trace"]) {
        const operationObject = pathItem[method];
        if (!operationObject)
            continue;
        const c = (0, utils_js_1.getSchemaObjectComment)(operationObject, indentLv);
        if (c)
            output.push((0, utils_js_1.indent)(c, indentLv));
        const keyedParameters = {};
        if (!("$ref" in operationObject)) {
            for (const parameter of [...(pathItem.parameters ?? []), ...(operationObject.parameters ?? [])]) {
                keyedParameters["$ref" in parameter ? parameter.$ref : parameter.name] = parameter;
            }
        }
        if ("$ref" in operationObject) {
            output.push((0, utils_js_1.indent)(`${method}: ${operationObject.$ref}`, indentLv));
        }
        else if (operationObject.operationId) {
            const operationType = (0, operation_object_js_1.default)({ ...operationObject, parameters: Object.values(keyedParameters) }, { path, ctx: { ...ctx, indentLv: 1 } });
            ctx.operations[operationObject.operationId] = {
                operationType,
                comment: (0, utils_js_1.getSchemaObjectComment)(operationObject, 1),
            };
            output.push((0, utils_js_1.indent)(`${method}: operations[${(0, utils_js_1.escStr)(operationObject.operationId)}];`, indentLv));
        }
        else {
            const operationType = (0, operation_object_js_1.default)({ ...operationObject, parameters: Object.values(keyedParameters) }, { path, ctx: { ...ctx, indentLv } });
            output.push((0, utils_js_1.indent)(`${method}: ${operationType};`, indentLv));
        }
    }
    if (pathItem.parameters?.length) {
        output.push((0, utils_js_1.indent)((0, operation_object_js_1.default)({ parameters: pathItem.parameters }, { path, ctx, wrapObject: false }).trim(), indentLv));
    }
    indentLv--;
    output.push((0, utils_js_1.indent)("}", indentLv));
    return output.join("\n");
}
exports.default = transformPathItemObject;
//# sourceMappingURL=path-item-object.js.map